
dialogId("odp-v-kachna", "font_big", "Doesn’t this duck look suspicious to you?")
dialogStr("Czy ta kaczka nie wydaje ci się podejrzana?")


dialogId("odp-m-zda0", "font_small", "I think it looks dumb.")
dialogStr("Wydaje mi się idiotyczna.")


dialogId("odp-m-zda1", "font_small", "I think it looks inflatable.")
dialogStr("Wygląda na dmuchaną.")


dialogId("odp-v-snehulak", "font_big", "Can you see that snowman?")
dialogStr("Widzisz tego bałwana?")


dialogId("odp-m-blaznis", "font_small", "What do you mean? Snowmen belong to the Mess Hall.")
dialogStr("Żartujesz sobie? Bałwany są w mesie okrętowej.")


dialogId("odp-m-kohout", "font_small", "Try to open that tap!")
dialogStr("Odkręć ten kurek!")


dialogId("odp-v-vtip", "font_big", "Now, this was a joke. Heh, heh.")
dialogStr("Ha ha, ale śmieszne.")


dialogId("odp-m-predmet", "font_small", "And there isn’t even a funny animated object here.")
dialogStr("U, nie ma tu żadnych animowanych przedmiotów.")


dialogId("odp-v-pozadi", "font_big", "But a beautifully wavy background.")
dialogStr("Za to tło ślicznie faluje.")


dialogId("odp-v-pohni", "font_big", "Move on, so that we can get going.")
dialogStr("Ruszaj się, nie mamy całego dnia.")


dialogId("odp-v-coja", "font_big", "And what about me?")
dialogStr("A co ze mną?")


dialogId("odp-v-nestacim", "font_big", "Am I not enough for you now, or what?")
dialogStr("To ja ci już nie wystarczam?")

